# Assigning Tags to Fact Sheets Based on Field Value Ranges
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#prerequisites)
  * [Step 1: Create a Custom Attribute for Energy Consumption on IT Component Fact Sheets](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#step-1:-create-a-custom-attribute-for-energy-consumption-on-it-component-fact-sheets)
  * [Step 2: Create a Tag Group for T-Shirt Sizes](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#step-2:-create-a-tag-group-for-t-shirt-sizes)
  * [Step 3: Create a Webhook for Energy Consumption Updates](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#step-3:-create-a-webhook-for-energy-consumption-updates)
  * [Step 4: Create a Function to Assign Tags](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#step-4:-create-a-function-to-assign-tags)
  * [Step 5: Update the Webhook with the Function URL](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#step-5:-update-the-webhook-with-the-function-url)
  * [Summary](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field#summary)


Learn how to set up an event-triggered automation to assign tags to IT component fact sheets based on the calculated energy consumption value.
